@@ -42,6 +42,7 @@ import time
 
 import plot_functions as pfunc
 
+dr_dic = {8:'dr8',9:'ls-dr9', 10:'ls-dr10-early-grz'}
 
 colormap = 'terrain'
 
@@ -594,7 +595,7 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
 
 def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                  region='circle', server=None, limtvel=500, xtpos=10, ytpos=20,
-                 deltay=10, ymin = 20, sky_box=[100, 100], deblend='off', psf=1,
+                 deltay=10, miny = 20, sky_box=[100, 100], deblend='off', psf=1,
                  usesimbad='no', band='R', field_size_phy=100, nsigma=2,
                  npixels=5, dilate_size=11, eta=0.2, show_plot='yes', run_auto='no',
                  outputfile='properties.dat'):
@@ -748,7 +749,7 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     if run_auto=='no':
         plot_simbad(gal, tab_gal, conn, size_image_phy=radsimbad, table=outsimbad,
                 add_object=False, xtpos=xtpos, ytpos=ytpos, deltay=deltay,
-                ymin = ymin, print_arp='no', print_scale='no',
+                miny = miny, print_arp='no', print_scale='no',
                 usesimbad=usesimbad, band=band)
 
     readn = 'images/fig_{}_{}kpc.png'.format(gal, size_image_phy)
@@ -1039,8 +1040,7 @@ def simbad_download(GAL, tab_gal, size_image_phy=100,  width = 300,
 
 def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
                      height = 300,  xtpos=10, ytpos=20, deltay=10, miny=20,
-                     labeltxt = 'off', limtvel=500, ned_plot='no',
-                     deltay_ned=12):
+                     minx=20, labeltxt = 'off', limtvel=500, ned_plot='no'):
 
 
     idg =np.where(tab_gal['gal']==GAL)[0][0]
@@ -1074,18 +1074,7 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
                      limtvel=limtvel, server=None)
     table = table[table['RV_VALUE']>0]
 
-
-
-    plt.figure(figsize=(10,10))
-    plt.imshow(ima_simbad, extent=np.array([-1,1,-1,1])*size_image_phy)
-
     galcoord = SkyCoord(ra*u.deg, dec*u.deg)
-
-    # Dowloading Ned Table
-    if ned_plot == 'yes':
-       table_ned = Ned.query_region(galcoord, radius=0.5*arcdist*u.arcsec)
-       table_ned = table_ned[table_ned['Velocity']>0]
-
     skyc=SkyCoord(table['RA_d'], table['DEC_d'])
     sep = galcoord.separation(skyc)
 
@@ -1096,12 +1085,21 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
     print ("------------------------")
     for i in np.arange(len(skyc)):
 
-        txt = "Proyected distance between "
+        txt = "Proyected distance "
         print (txt+"{} and ({}) {} ({} km/s) is = {:.1f}\\,kpc ({:.1f}$\\arcsec$)".format(
         GAL, i, table['MAIN_ID'][i], table['RV_VALUE'][i], sep_kpc[i],
         sep.arcsec[i]))
 
 
+
+    if ned_plot == 'yes':
+        plt.figure(figsize=(20,10))
+        plt.subplot(121)
+    else:
+        plt.figure(figsize=(10,10))
+        plt.subplot(111)
+    plt.imshow(ima_simbad, extent=np.array([-1,1,-1,1])*size_image_phy)
+
     w = wcs.WCS(hdu[0].header)
     Xgc, Ygc = w.all_world2pix(table['RA_d'], table['DEC_d'], 0)
 
@@ -1118,8 +1116,37 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
     plt.scatter(Xgc[cond], Ygc[cond], s=100, facecolors='none',
             edgecolors='g')
 
+    ordem= np.argsort(Ygc)
+    cond = cond[ordem]
+
+    if labeltxt == 'on':
+        for i, indg in enumerate(ordem[cond]):
+            textl = str(table['OTYPE'][indg]) + ' Vrad={:.0f} ({})'.format(
+                    table['RV_VALUE'][indg], indg)
+
+            xpos = Xgc[ordem][cond][i] + xtpos
+            ypos = Ygc[ordem][cond][i] + ytpos
+
+            if i==0:
+                plt.text(xpos, ypos, textl, fontsize=12, color='w')
+
+            else:
+                yposb = Ygc[ordem][cond][i-1]
+                xposb = Xgc[ordem][cond][i-1]
+                if abs(ypos - yposb)<miny and abs(xpos - xposb) < minx:
+                    ypos+=deltay
+                if i>1:
+                    yposbb = Ygc[ordem][cond][i-2]
+                    xposbb = Xgc[ordem][cond][i-2]
+                    if abs(ypos - yposbb)<miny*2 and abs(xpos - xposbb) < minx*2:
+                        ypos+=deltay
+
+                plt.text(xpos, ypos, textl, fontsize=12, color='w')
 
     if ned_plot == 'yes':
+        # Dowloading NED TABLE
+        table_ned = Ned.query_region(galcoord, radius=0.5*arcdist*u.arcsec)
+        table_ned = table_ned[table_ned['Velocity']>0]
 
         ned_ra  = table_ned['RA']
         ned_dec = table_ned['DEC']
@@ -1134,6 +1161,11 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
                      (Xgc_ned<0.5*scima*ima.shape[1]) &
                      (Ygc_ned<0.5*scima*ima.shape[0]))
 
+        plt.xlabel('x (kpc)')
+        plt.ylabel('y (kpc)')
+        plt.minorticks_on()
+        plt.subplot(122)
+        plt.imshow(ima_simbad, extent=np.array([-1,1,-1,1])*size_image_phy)
         plt.scatter(Xgc_ned[cond_ned], Ygc_ned[cond_ned],
                     s=100, marker='x', color='r')
         print('')
@@ -1150,39 +1182,14 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
         sep_kpc = sep.arcsec*kpc_arc
 
         print('')
+        print (Fore.BLUE + "\nProjected Distances")
+        print ("------------------------")
         for i in np.arange(len(skyc)):
-            txt = "Proyected distance between "
+            txt = "Proyected distance "
             print (txt+"{} and ({}) {} ({} km/s) is = {:.1f}\\,kpc ({:.1f}$\\arcsec$)".format(
             GAL, i, table_ned['Object Name'][i], table_ned['Velocity'][i],
             sep_kpc[i], sep.arcsec[i]))
 
-    ordem= np.argsort(Ygc)
-    cond = cond[ordem]
-
-
-    if labeltxt == 'on':
-        for i, indg in enumerate(ordem[cond]):
-            textl = str(table['OTYPE'][indg]) + ' Vrad={:.0f} ({})'.format(
-                    table['RV_VALUE'][indg], indg)
-
-            xpos = Xgc[ordem][cond][i] + xtpos
-            ypos = Ygc[ordem][cond][i] + ytpos
-
-            if i==0:
-                plt.text(xpos, ypos, textl, fontsize=12, color='w')
-
-            else:
-                yposb = Ygc[ordem][cond][i-1] + ytpos
-                if abs(ypos - yposb)<miny:
-                    #print ('hola', i)
-                    ypos+=deltay
-                if i>1:
-                    yposbb = Ygc[ordem][cond][i-2] + ytpos
-                    if abs(ypos - yposbb)<miny*2:
-                        ypos+=deltay
-
-                plt.text(xpos, ypos, textl, fontsize=12, color='w')
-
     if labeltxt == 'on' and ned_plot == 'yes':
         ordem= np.argsort(Ygc_ned)
         cond_ned = cond_ned[ordem]
@@ -1191,19 +1198,19 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
                     table_ned['Velocity'][indg], indg))
 
             xpos = Xgc_ned[ordem][cond_ned][i] + xtpos
-            ypos = Ygc_ned[ordem][cond_ned][i] + ytpos - deltay_ned
+            ypos = Ygc_ned[ordem][cond_ned][i] + ytpos
 
             if i==0:
                 plt.text(xpos, ypos, textl, fontsize=12, color='r')
-
             else:
-                yposb = Ygc_ned[ordem][cond_ned][i-1] + ytpos - deltay_ned
-                if abs(ypos - yposb)<miny:
-                    #print ('hola', i)
+                yposb = Ygc_ned[ordem][cond_ned][i-1]
+                xposb = Xgc_ned[ordem][cond_ned][i-1]
+                if abs(ypos - yposb)<miny and abs(xpos - xposb) < minx :
                     ypos+=deltay
                 if i>1:
-                    yposbb = Ygc_ned[ordem][cond_ned][i-2] + ytpos - deltay_ned
-                    if abs(ypos - yposbb)<miny*2:
+                    yposbb = Ygc_ned[ordem][cond_ned][i-2]
+                    xposbb = Xgc_ned[ordem][cond_ned][i-2]
+                    if abs(ypos - yposbb)<miny*2 and abs(xpos - xposbb) < minx*2:
                         ypos+=deltay
 
                 plt.text(xpos, ypos, textl, fontsize=12, color='r')
@@ -1216,7 +1223,7 @@ def simbad_thumbnail(GAL, tab_gal, size_image_phy=100,  width = 300,
 
 
 def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
-                user_text=None, xtpos=10, ytpos=20, deltay=10, miny=20,
+                user_text=None, xtpos=10, ytpos=20, deltay=10, miny=20, minx=20,
                 savefig=None, add_object=True, itsconsider='no', itsgroup='off',
                 Nmembers=0, print_arp='yes', print_scale='yes',
                 usesimbad = 'no', band='R', outputfile='properties.dat'):
@@ -1246,6 +1253,7 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         print(AM['desc','codes'][np.where(AM['gal']==gal)[0]])
 
     if add_object:
+        print(" ")
         data = ascii.read(outputfile)
 
         ind_inters = np.intersect1d(data['GAL'], user_text, return_indices=True)
@@ -1397,7 +1405,6 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
 
     if user_order is None:
 
-
         plt.scatter(Xgc[cond], Ygc[cond], s=100, facecolors='none',
                     edgecolors='g')
 
@@ -1413,11 +1420,13 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
 
             else:
                 yposb = Ygc[ordem][cond][i-1]
-                if abs(ypos - yposb)<miny:
+                xposb = Xgc[ordem][cond][i-1]
+                if abs(ypos - yposb)<miny and abs(xpos - xposb) < minx:
                     ypos+=deltay
                 if i>1:
                     yposbb = Ygc[ordem][cond][i-2]
-                    if abs(ypos - yposbb)<miny*2:
+                    xposbb = Xgc[ordem][cond][i-2]
+                    if abs(ypos - yposbb)<miny*2 and abs(xpos - xposbb) < minx*2:
                         ypos+=deltay
 
                 plt.text(xpos, ypos, textl, fontsize=12, color='w')
@@ -1427,7 +1436,6 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         plt.xlabel('$\Delta \\alpha$ (arcsec)')
         plt.show()
 
-
     else:
         ind_inters = np.intersect1d(data['GAL'], user_text, return_indices=True)
         Xgc, Ygc = w.all_world2pix(data['ra'][ind_inters[1]]*u.deg,
@@ -1444,7 +1452,6 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         plt.scatter(Xgc, Ygc, s=100, facecolors='none',
                     edgecolors='g')
 
-
         for i, indg in enumerate(user_order):
             textl = user_text[i]
 
@@ -1457,15 +1464,19 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
                 plt.text(xpos, ypos, textl, fontsize=12, color='w')
             else:
                 #yposb = Ygc[user_order][i-1]
-                yposb = Ygc[-1]
+                yposb = Ygc[i-1]
+                xposb = Xgc[i-1]
 
-                if abs(ypos - yposb)<miny:
+                if abs(ypos - yposb)<miny  and abs(xpos - xposb) < minx :
                     ypos+=deltay
+                    print("sum deltay")
                 if i>1:
                     #yposbb = Ygc[user_order][i-2]
                     yposbb = Ygc[i-2]
-                    if abs(ypos - yposbb)<miny*2:
-                        ypos+=deltay
+                    xposbb = Xgc[i-2]
+                    if abs(ypos - yposbb)<miny*2 and abs(xpos - xposbb) < minx*2:
+                        print("sum deltay2")
+                        ypos+=deltay*2
 
                 plt.text(xpos, ypos, textl, fontsize=12, color='w')
 
@@ -1475,27 +1486,28 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         if savefig is not None:
             print ("\nSaving figure in images/{}.png".format(gal))
             plt.savefig('images/{}.png'.format(gal), bbox_inches='tight')
-        #plt.show()
-        Xgc, Ygc = w.all_world2pix(tab_gal['ra'][idg]*u.deg,
-                                   tab_gal['dec'][idg]*u.deg, 0)
 
         if usesimbad == 'yes':
             path = 'fits_images/{}_simbad_{}kpc.fits'.format(gal, size_image_phy)
         else:
             path = 'fits_images/{}_{}kpc.fz'.format(gal, size_image_phy)
 
+        #################################################################
+        # pritting info to add manually the coordinates
+
+        ima_centX, ima_centY = w.all_world2pix(tab_gal['ra'][idg]*u.deg,
+                                   tab_gal['dec'][idg]*u.deg, 0)
 
         print (Fore.GREEN + "\nIn case  to add manually the coordinates:")
-        print ("------------------------")
-        print ("\n")
-        print ("from astropy.wcs import wcs")
+        print ("--------------------------------------------------------")
+        print ("\nfrom astropy.wcs import wcs")
         print ("ima = fits.open('{}')[1]".format(path))
         print ("w =  wcs.WCS(ima.header)")
         print ("coord_a = SkyCoord('{} {}', unit=u.deg)".format(
                data['ra'][ind_inters[1][0]], data['dec'][ind_inters[1][0]]))
-        print ("coord_b = w.all_pix2world({} + delta_ra/{}*-1,".format(Xgc,
+        print ("coord_b = w.all_pix2world({} + delta_ra/{}*-1,".format(ima_centX,
                                                                     pix_scima))
-        print ("                          {} + delta_dec/{}, 0)".format(Ygc,
+        print ("                          {} + delta_dec/{}, 0)".format(ima_centY,
                                                                      pix_scima))
         print ("print (\"{:.7f} {:.7f}\".format(coord_b[0], coord_b[1]))")
 
@@ -1515,12 +1527,26 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         print ("tab_pro['D_to_main'][ind_g] = sep_kpc")
         print ("tab_pro.write('properties.dat', format='ascii', overwrite=True)")
 
+        #################################################################
+        # pritting info to compute manually the distance between galaxies
+        print (Fore.BLACK + "\nIn case  to compute manually the distance between galaxies:")
+        print ("--------------------------------------------------------")
+        print ("\nfrom astropy.wcs import wcs")
+        for galid, i in enumerate(ind_inters[1][:]) :
+            print ("coord_{} = SkyCoord('{} {}', unit=u.deg)".format(
+                   galid, data['ra'][i], data['dec'][i]))
+
+        print ("\nsep = coord_0.separation(coord_1)")
+        print ("arc_kpc = {}".format(arc_kpc))
+        print ("sep_kpc = sep.arcsec*arc_kpc")
+        print ("print ('Separation between a Secondary and Primary" +
+               " $\\sim$ {:.1f}\\,kpc ({:.1f}$\\\\arcsec$)'.format(sep_kpc, sep.arcsec))")
 
 def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
                         areagal=2, band='r', sky_box=[100, 100], deblend='off',
                         psf=1, run_auto='no', show_plot='yes',
                         nsigma=2, npixels=5, dilate_size=11,
-                        outputfile='properties.dat'):
+                        outputfile='properties.dat', dr=8):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -1554,8 +1580,9 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
     path = 'fits_images/{}_{}_{}kpc.fits'.format(gal, band, size_image_phy)
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
-        part0 = 'ra={}&dec={}&layer=dr8&pixscale=0.27&bands={}&size={}'.format(
-             tab_gal['ra'][idg], tab_gal['dec'][idg], band, int(size_image))
+        part0 = 'ra={}&dec={}&layer={}&pixscale=0.27&bands={}&size={}'.format(
+             tab_gal['ra'][idg], tab_gal['dec'][idg], band, dr_dic[dr],
+                     int(size_image))
         targ = home + part0
         print (targ)
         #wget.download(targ, out=path)
@@ -1568,8 +1595,9 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
     path = 'images/fig_{}_{}kpc.jpeg'.format(gal, size_image_phy)
     if not os.path.exists(path):
         print ('\nDownloading the jpeg file..')
-        part0 = 'ra={}&dec={}&layer=dr8&pixscale=0.27&bands=grz&size={}'.format(
-             tab_gal['ra'][idg], tab_gal['dec'][idg], int(size_image))
+        part0 = 'ra={}&dec={}&layer={}&pixscale=0.27&bands=grz&size={}'.format(
+             tab_gal['ra'][idg], tab_gal['dec'][idg], dr_dic[dr],
+                     int(size_image))
         targ = home + part0
         print (targ)
         #wget.download(targ, out=path)
@@ -1951,7 +1979,7 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
     plt.show()
 
 def mass_decals(gal, tab_gal, size_image_phy, outputfile='properties.dat',
-                suf_num=-1, show_plot='yes'):
+                suf_num=-1, show_plot='yes', dr=8):
 
     import functions as func
 
@@ -1969,8 +1997,9 @@ def mass_decals(gal, tab_gal, size_image_phy, outputfile='properties.dat',
             size_image_phy)
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
-        part0 = 'ra={}&dec={}&layer=dr8&pixscale=0.27&bands=g&size={}'.format(
-             tab_gal['ra'][idg], tab_gal['dec'][idg], int(size_image))
+        part0 = 'ra={}&dec={}&layer={}&pixscale=0.27&bands=g&size={}'.format(
+             tab_gal['ra'][idg], tab_gal['dec'][idg], dr_dic[dr],
+                     int(size_image))
         targ = home + part0
         print (targ)
 
@@ -1984,8 +2013,9 @@ def mass_decals(gal, tab_gal, size_image_phy, outputfile='properties.dat',
            size_image_phy)
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
-        part0 = 'ra={}&dec={}&layer=dr8&pixscale=0.27&bands=r&size={}'.format(
-             tab_gal['ra'][idg], tab_gal['dec'][idg], int(size_image))
+        part0 = 'ra={}&dec={}&layer={}&pixscale=0.27&bands=r&size={}'.format(
+             tab_gal['ra'][idg], tab_gal['dec'][idg], dr_dic[dr],
+                     int(size_image))
         targ = home + part0
         print (targ)
         #wget.download(targ, out=path)
